<template>
  <div class="app-container">
    <el-form :model="filters" :inline="true">
      <el-form-item label="采购合同号">
        <el-input
          v-model="filters.purchaseContractNumber"
          style="width: 240px"
          placeholder="请输入"
          clearable
          :prefix-icon="Search"
          @change="getTableData"
        />
      </el-form-item>
      <el-form-item label="供应商">
        <el-input
          v-model="filters.supplierName"
          style="width: 240px"
          placeholder="请输入"
          clearable
          :prefix-icon="Search"
          @change="getTableData"
        />
      </el-form-item>
      <el-form-item label="来票日期">
        <el-date-picker
          style="width: 240px"
          v-model="filters.createdAt"
          value-format="YYYY-MM-DD"
          format="YYYY-MM-DD"
          type="daterange"
          start-placeholder="开始时间"
          end-placeholder="结束时间"
          clearable
          @change="getTableData"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" @click="getTableData">搜索</el-button>
        <el-button @click="resetFilters"> 重置 </el-button>
        <el-button @click="handleOut">导出</el-button>
      </el-form-item>
    </el-form>
    <div class="table_list">
      <PIMTable
        rowKey="id"
        :column="columns"
        :tableLoading="loading"
        :tableData="dataList"
        :isSelection="true"
        height="calc(100vh - 15em)"
        :isShowSummary="true"
        :summaryMethod="summarizeMainTable"
        :page="{
          current: pagination.currentPage,
          size: pagination.pageSize,
          total: 0,
        }"
        @selection-change="handleSelectionChange"
        @pagination="onCurrentChange"
      >
        <template #commonFilesRef="{ row }">
          <el-button
            v-if="row.commonFiles.length !== 0"
            text
            icon="Files"
            type="danger"
            @click="handleFiles(row.commonFiles)"
          >
            附件下载
          </el-button>
          <el-text v-else type="danger">暂无附件</el-text>
        </template>
      </PIMTable>
    </div>
  </div>
</template>

<script setup>
import { ref, getCurrentInstance } from "vue";
import { usePaginationApi } from "@/hooks/usePaginationApi";
import { Search } from "@element-plus/icons-vue";
import { productRecordPage } from "@/api/procurementManagement/procurementInvoiceLedger.js";
import { onMounted } from "vue";
import { ElMessageBox } from "element-plus";

defineOptions({
  name: "来票台账",
});

const { proxy } = getCurrentInstance();
const multipleVal = ref([]);
const {
  loading,
  filters,
  columns,
  dataList,
  pagination,
  getTableData,
  resetFilters,
  onCurrentChange,
} = usePaginationApi(
  productRecordPage,
  {
    purchaseContractNumber: undefined, // 采购合同号
    supplierName: undefined, // 供应商
    createdAt: [], // 来票日期
  },
  [
    {
      label: "采购合同号",
      prop: "purchaseContractNumber",
      align: "center",
    },
    {
      label: "销售合同号",
      prop: "salesContractNo",
      align: "center",
    },
    {
      label: "客户名称",
      prop: "customerName",
      align: "center",
    },
    {
      label: "供应商名称",
      prop: "supplierName",
      align: "center",
    },
    {
      label: "规格型号",
      prop: "specificationModel",
      align: "center",
    },
    {
      label: "发票号",
      prop: "invoiceNumber",
      align: "center",
    },
    {
      label: "合同金额(元)",
      prop: "taxInclusiveTotalPrice",
      align: "center",
      formatData: (cell) => {
        return cell ? parseFloat(cell).toFixed(2) : 0;
      },
    },
    {
      label: "开票日期",
      prop: "createdAt",
      align: "center",
    },
    {
      label: "开票金额",
      prop: "ticketsAmount",
      align: "center",
      formatData: (cell) => {
        return cell ? parseFloat(cell).toFixed(2) : 0;
      },
    },
    {
      label: "不含税金额",
      prop: "unTicketsPrice",
      align: "center",
      formatData: (cell) => {
        return cell ? parseFloat(cell).toFixed(2) : 0;
      },
    },
    {
      label: "增值税",
      prop: "invoiceAmount",
      align: "center",
    },
    {
      label: "附件",
      align: "center",
      prop: "commonFiles",
      dataType: "slot",
      slot: "commonFilesRef",
      width: 150,
    },
    // {
    //   fixed: "right",
    //   width: 120,
    //   label: "操作",
    //   dataType: "slot",
    //   slot: "operation",
    //   align: "center",
    // },
  ],
  {},
  {
    createdAt: (aim) => ({
      createdAtStart: aim ? aim[0] : undefined,
      createdAtEnd: aim ? aim[1] : undefined,
    }),
  }
);

// 主表合计方法
const summarizeMainTable = (param) => {
  return proxy.summarizeTable(
    param,
    [
      "taxInclusiveTotalPrice",
      "ticketsAmount",
      "unTicketsPrice",
      "invoiceAmount",
    ],
    {
      ticketsNum: { noDecimal: true }, // 不保留小数
      futureTickets: { noDecimal: true }, // 不保留小数
    }
  );
};

const handleSelectionChange = (val) => {
  multipleVal.value = val;
};

// 导出
const handleOut = () => {
  ElMessageBox.confirm("选中的内容将被导出，是否确认导出？", "导出", {
    confirmButtonText: "确认",
    cancelButtonText: "取消",
    type: "warning",
  })
    .then(() => {
      proxy.download("/purchase/registration/export", {}, "来票登记.xlsx");
    })
    .catch(() => {
      proxy.$modal.msg("已取消");
    });
};

const handleFiles = (fileList) => {
  fileList.forEach((e) => {
    proxy.$download.name(e.url);
  });
};

onMounted(() => {
  getTableData();
});
</script>

<style lang="scss" scoped>
.table_list {
  margin-top: unset;
}
.tagBox {
  margin-top: 4px;
}
</style>
